#!/usr/bin/env python
# -*- coding: utf-8 -*-

import json
import traceback

from jinja2 import Environment
from jinja2 import FileSystemLoader


def to_json(obj, *args, **kw):
    ''' Convert the value to JSON '''
    return json.dumps(obj, *args, **kw)


def to_raw_json(obj, *args, **kw):
    ''' Convert the value to JSON,delete the first and last \" '''
    return json.dumps(obj, *args, **kw)[1:-1]


def to_nice_json(obj, *args, **kw):
    '''Make verbose, human readable JSON'''
    return json.dumps(obj, indent=4, sort_keys=True, *args, **kw)


class Templar:
    '''
    Define the class for ruling the template format display
    '''

    def __init__(self, templatedir):
        self._templateenv = Environment(loader=FileSystemLoader(templatedir))
        self._templateenv.filters['to_json'] = to_json
        self._templateenv.filters['to_nice_json'] = to_nice_json
        self._templateenv.filters['to_raw_json'] = to_raw_json
        self._templatedir = templatedir

    def render(self, templatefile, **var):
        """Add template"""
        try:
            tempfile = self._templateenv.get_template(templatefile)
            out = tempfile.render(**var)
            return True, out
        except:
            return False, traceback.format_exc()
